import 'package:flutter/material.dart';
import 'package:html_unescape/html_unescape.dart';

String truncate(String text, {int length = 20, String omission = '...'}) {
  if (length >= text.length) {
    return text;
  }
  return text.replaceRange(length, text.length, omission);
}

Widget assetRow(String barcode, BuildContext context,
    {String? name,
    String? note,
    bool? status,
    String? checkinFrom,
    String? checkoutTo}) {
  Size size = MediaQuery.of(context).size;
  return Column(
    children: [
      Row(children: [
        Container(
            padding: const EdgeInsets.only(left: 20, bottom: 10),
            width: size.width * 0.4,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                const Text(
                  "Scanned barcode",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                Text(truncate(barcode, length: 20))
              ],
            )),
        if (name != null)
          Container(
              padding: const EdgeInsets.only(left: 20, bottom: 10),
              width: size.width * 0.4,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Text(
                    "Asset name",
                    style: TextStyle(fontWeight: FontWeight.bold),
                  ),
                  InkWell(
                      child: Text(
                        truncate(HtmlUnescape().convert(name), length: 20),
                        style: const TextStyle(color: Colors.lightBlue),
                      ),
                      onTap: () => {
                            Navigator.pushNamed(context, '/assetDetail',
                                arguments: barcode)
                          })
                ],
              )),
        Container(
            padding: const EdgeInsets.only(left: 20, bottom: 10),
            width: size.width * 0.2,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                const Text(
                  "Status",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                if (status != null && status)
                  const Icon(
                    Icons.check,
                    color: Colors.green,
                  ),
                if (status != null && !status)
                  const Icon(
                    Icons.cancel,
                    color: Colors.red,
                  ),
                if (status == null)
                  Container(
                    padding: const EdgeInsets.all(4.0),
                    child: const SizedBox(
                      height: 16.0,
                      width: 16.0,
                      child: CircularProgressIndicator(),
                    ),
                  )
              ],
            )),
      ]),
      Row(
        children: [
          if (checkinFrom != null && checkinFrom != "")
            Container(
                padding: const EdgeInsets.only(left: 20, bottom: 10),
                width: size.width * 0.4,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    const Text(
                      "Checkin from",
                      style: TextStyle(fontWeight: FontWeight.bold),
                    ),
                    Text(truncate(HtmlUnescape().convert(checkinFrom))),
                  ],
                )),
          if (checkoutTo != null && checkoutTo != "")
            Container(
                padding: const EdgeInsets.only(left: 20, bottom: 10),
                width: size.width * 0.4,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    const Text(
                      "Checkin from",
                      style: TextStyle(fontWeight: FontWeight.bold),
                    ),
                    Text(
                      truncate(HtmlUnescape().convert(checkoutTo)),
                    )
                  ],
                )),
          if (note != null && note != "")
            Container(
                padding: const EdgeInsets.only(left: 20, bottom: 10),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    const Text(
                      "Note",
                      style: TextStyle(fontWeight: FontWeight.bold),
                    ),
                    Text(truncate(HtmlUnescape().convert(note), length: 30))
                  ],
                ))
        ],
      ),
      const Divider()
    ],
  );
}
