import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:html_unescape/html_unescape.dart';
import 'package:snipe_scanner/model/comparable_with_id.dart';

class DropdownSearchInput<T extends ComparableWithId> extends StatelessWidget {
  final void Function(int?) cb;
  final String label;
  final Future<List<T>> Function(String) getItems;
  const DropdownSearchInput(
      {super.key, required this.cb, required this.label, required this.getItems});

  @override
  Widget build(BuildContext context) {
    return DropdownSearch<T>(
        dropdownDecoratorProps: DropDownDecoratorProps(
            dropdownSearchDecoration: InputDecoration(labelText: this.label)),
        popupProps: const PopupProps.modalBottomSheet(
            showSelectedItems: true,
            showSearchBox: true,
            isFilterOnline: true,
            searchDelay: Duration(milliseconds: 300)),
        asyncItems: this.getItems,
        itemAsString: (ComparableWithId? a) =>
            HtmlUnescape().convert(a!.getName()),
        onChanged: (c) => this.cb(c!.id),
        compareFn: (a, b) => a.equals(b));
  }
}
