import 'package:flutter/material.dart';
import 'package:html_unescape/html_unescape.dart';
import 'package:snipe_scanner/model/activity.dart';

Widget _rowIcon(String activity) {
  if (activity == "checkin from") return const Icon(Icons.south_west);
  if (activity == "zurücknehmen von") return const Icon(Icons.south_west);
  if (activity == "checkout") return const Icon(Icons.north_east);
  if (activity == "herausgeben") return const Icon(Icons.north_east);
  if (activity == "audit") return const Icon(Icons.qr_code);
  return const Icon(Icons.cloud_queue);
}

Widget historyRow(Activity activity, BuildContext context) {
  Size size = MediaQuery.of(context).size;
  return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 20),
      child: Column(
        children: [
          Row(
            children: [
              _rowIcon(activity.actionType!),
              Expanded(
                child: Column(
                  children: [
                    Row(children: [
                      Container(
                          padding: const EdgeInsets.only(left: 20, bottom: 10),
                          width: size.width * 0.4,
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              const Text(
                                "Date",
                                style: TextStyle(fontWeight: FontWeight.bold),
                              ),
                              Text(activity.actionDate!.formatted)
                            ],
                          )),
                      if (activity.admin != null &&
                          activity.admin!.name != null)
                        Expanded(
                          child: Container(
                              padding:
                                  const EdgeInsets.only(left: 20, bottom: 10),
                              width: size.width * 0.4,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  const Text(
                                    "Admin",
                                    style:
                                        TextStyle(fontWeight: FontWeight.bold),
                                  ),
                                  InkWell(
                                    child: Text(
                                      HtmlUnescape()
                                          .convert(activity.admin!.name!),
                                      style: const TextStyle(
                                          color: Colors.lightBlue),
                                    ),
                                    onTap: () => Navigator.pushNamed(
                                        context, '/userDetail',
                                        arguments: activity.admin!.id),
                                  )
                                ],
                              )),
                        )
                    ]),
                    Row(children: [
                      Container(
                          padding: const EdgeInsets.only(left: 20, bottom: 10),
                          width: size.width * 0.4,
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              const Text(
                                "Action",
                                style: TextStyle(fontWeight: FontWeight.bold),
                              ),
                              Text(activity.actionType!),
                            ],
                          )),
                      if (activity.target != null &&
                          activity.target!.name != null)
                        Expanded(
                          child: Container(
                              padding:
                                  const EdgeInsets.only(left: 20, bottom: 10),
                              width: size.width * 0.4,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  const Text(
                                    "Target",
                                    style:
                                        TextStyle(fontWeight: FontWeight.bold),
                                  ),
                                  InkWell(
                                    child: Text(
                                      HtmlUnescape()
                                          .convert(activity.target!.name!),
                                      style: const TextStyle(
                                          color: Colors.lightBlue),
                                    ),
                                    onTap: () => Navigator.pushNamed(
                                        context, '/userDetail',
                                        arguments: activity.target!.id),
                                  )
                                ],
                              )),
                        )
                    ]),
                    Row(
                      children: [
                        Expanded(
                          child: Container(
                              padding: const EdgeInsets.only(left: 20),
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  const Text(
                                    "Note",
                                    style:
                                        TextStyle(fontWeight: FontWeight.bold),
                                  ),
                                  Text(
                                    HtmlUnescape()
                                        .convert(activity.note ?? " - "),
                                  )
                                ],
                              )),
                        )
                      ],
                    ),
                  ],
                ),
              )
            ],
          ),
          const Divider()
        ],
      ));
}
