import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:snipe_scanner/components/dropdown_search_input.dart';
import 'package:snipe_scanner/model/app_state.dart';
import 'package:snipe_scanner/model/location.dart';
import 'package:snipe_scanner/service/location.dart';

class LocationSelector extends StatefulWidget {
  final Function(int) cb;
  final bool instant;
  const LocationSelector({super.key, required this.cb, required this.instant});

  @override
  State<LocationSelector> createState() => _LocationSelectorState();
}

class _LocationSelectorState extends State<LocationSelector> {
  int _dst = -1;
  Future<List<Location>> _getItems(String filter) async {
    var token = Provider.of<AppState>(context, listen: false).token;
    return await getLocations(token, filter);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }

  void _setDst(int? dst) {
    setState(() {
      _dst = dst ?? -1;
    });
    if (widget.instant) {
      widget.cb(dst ?? -1);
    }
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      padding: const EdgeInsets.symmetric(horizontal: 40),
      child: Row(
        children: [
          Row(children: [
            SizedBox(
                width: size.width - 80 - (widget.instant ? 0 : 60),
                child: DropdownSearchInput<Location>(
                  cb: _setDst,
                  label: 'Select location',
                  getItems: _getItems,
                )),
            if (!widget.instant)
              Padding(
                padding: const EdgeInsets.only(left: 10),
                child: Container(
                  color: Colors.black12,
                  child: IconButton(
                    icon: const Icon(Icons.arrow_right_alt),
                    tooltip: 'Select location',
                    onPressed: () => widget.cb(_dst),
                  ),
                ),
              )
          ])
        ],
      ),
    );
  }
}
