import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:snipe_scanner/components/dropdown_search_input.dart';
import 'package:snipe_scanner/model/app_state.dart';
import 'package:snipe_scanner/model/asset.dart';
import 'package:snipe_scanner/model/location.dart';
import 'package:snipe_scanner/model/user.dart';
import 'package:snipe_scanner/service/asset.dart';
import 'package:snipe_scanner/service/users.dart';

import '../service/location.dart';

class TargetSelector extends StatefulWidget {
  final Function(String, int) cb;
  const TargetSelector({super.key, required this.cb});

  @override
  State<TargetSelector> createState() => _TargetSelectorState();
}

class _TargetSelectorState extends State<TargetSelector> {
  String _type = "user";
  int _dst = 0;
  Future<List<User>> _getUsers(String search) async {
    var token = Provider.of<AppState>(context, listen: false).token;
    return await getUsers(token, search);
  }

  Future<List<Location>> _getLocations(String search) async {
    var token = Provider.of<AppState>(context, listen: false).token;
    return await getLocations(token);
  }

  Future<List<Asset>> _getAssets(String filter) async {
    var token = Provider.of<AppState>(context, listen: false).token;
    return await getAssets(token, filter);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }

  void _setDst(int dst) {
    setState(() {
      _dst = dst;
    });
    widget.cb(_type, _dst);
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      padding: const EdgeInsets.symmetric(horizontal: 40),
      child: Row(
        children: [
          Container(
            padding: const EdgeInsets.only(right: 20),
            child: SizedBox(
              width: 80,
              child: DropdownButtonFormField<String>(
                  decoration: const InputDecoration(
                      labelText: 'Select type', isDense: true),
                  value: _type,
                  items: const [
                    DropdownMenuItem<String>(
                        value: "user", child: Text("Person")),
                    DropdownMenuItem<String>(
                        value: "location", child: Text("Ort")),
                    DropdownMenuItem<String>(
                        value: "asset", child: Text("Asset")),
                  ],
                  onChanged: (c) {
                    setState(() {
                      if (_type != c) {
                        _dst = 0;
                      }
                      _type = c!;
                    });
                  }),
            ),
          ),
          if (_type == "user")
            Row(children: [
              SizedBox(
                  width: size.width - 180,
                  child: DropdownSearchInput<User>(
                    cb: (c) => _setDst(c!),
                    label: 'Select user',
                    getItems: _getUsers,
                  )),
            ]),
          if (_type == "location")
            Row(
              children: [
                SizedBox(
                    width: size.width - 180,
                    child: DropdownSearchInput<Location>(
                      cb: (c) => _setDst(c!),
                      label: 'Select location',
                      getItems: _getLocations,
                    )),
              ],
            ),
          if (_type == "asset")
            Row(
              children: [
                SizedBox(
                    width: size.width - 180,
                    child: DropdownSearchInput<Asset>(
                      cb: (c) => _setDst(c!),
                      label: 'Select asset',
                      getItems: _getAssets,
                    )),
              ],
            ),
        ],
      ),
    );
  }
}
