/* 
  Here are all the http requests to login a user
*/
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snipe_scanner/main.dart';
import 'package:snipe_scanner/model/login_user.dart';
import 'package:snipe_scanner/model/user.dart';

class HttpException implements Exception {
  late String cause;
  late int code;
  late String body;
  HttpException(int c, String b) {
    cause = "HTTP Error: $c";
    code = c;
    body = b;
  }

  @override
  String toString() {
    return "HTTP Error $code: $body";
  }
}

class SnipeException implements Exception {
  late String message;
  SnipeException(String b) {
    message = b;
  }

  @override
  String toString() {
    return message;
  }
}

// get the login users using the scanner_users.json
Future<List<LoginUser>> getLoginUsers() async {
  var url = "${service.get('host')}/scanner_users.json";
  if (service.get<bool>('use_custom_user_url')!) {
    url = service.get<String>('custom_user_url')!;
  }
  if (url == "") {
    return List<LoginUser>.empty();
  }
  final response = await http.get(Uri.parse(url), headers: {
    HttpHeaders.contentTypeHeader: 'application/json; charset=UTF-8',
    HttpHeaders.acceptHeader: 'application/json',
  });
  if (response.statusCode != 200) {
    throw HttpException(response.statusCode, response.body);
  }
  final responseJson = jsonDecode(utf8.decode(response.bodyBytes));
  List<LoginUser> loginUsers =
      (responseJson as List).map((i) => LoginUser.fromJson(i)).toList();
  return loginUsers;
}

Future<User> getUser(String token) async {
  final response = await http
      .get(Uri.parse("${service.get('host')}/api/v1/users/me"), headers: {
    HttpHeaders.authorizationHeader: 'Bearer $token',
    HttpHeaders.contentTypeHeader: 'application/json; charset=UTF-8',
    HttpHeaders.acceptHeader: 'application/json'
  });
  final responseJson = jsonDecode(utf8.decode(response.bodyBytes));
  if (response.statusCode != 200) {
    throw HttpException(response.statusCode, response.body);
  }
  return User.fromJson(responseJson);
}
