/* 
  Here are all the http requests to handle users
*/
import 'dart:convert';
import 'dart:io';

import 'package:catcher_2/catcher_2.dart';
import 'package:http/http.dart' as http;
import 'package:snipe_scanner/model/user.dart';

import '../main.dart';

// gets all users that match the optional search parameter
Future<List<User>> getUsers(String token, [String search = ""]) async {
  final response = await http.get(
      Uri.parse(
          "${service.get('host')}/api/v1/users?sort=name&order=asc&search=$search"),
      headers: {
        HttpHeaders.authorizationHeader: 'Bearer $token',
        HttpHeaders.contentTypeHeader: 'application/json; charset=UTF-8',
      });
  // snipe api definition does only specify 200 and 400 as response code, not sure what appens because it's not documented.
  if (response.statusCode != 200) {
    throw Error();
  }
  // parse the json
  final responseJson = jsonDecode(utf8.decode(response.bodyBytes));
  // create a list of users using the json response
  List<User> users = List.empty(growable: true);
  // try to catch errors while parsing the json, because snipe is stupid and regularly changes the responses on accident..
  try {
    users =
        (responseJson["rows"] as List).map((i) => User.fromJson(i)).toList();
  } catch (error, stackTrace) {
    Catcher2.reportCheckedError(error, stackTrace);
  }
  return users;
}

// get a single user using the user id
Future<User> getUser(String token, int id) async {
  final response = await http
      .get(Uri.parse("${service.get('host')}/api/v1/users/$id"), headers: {
    HttpHeaders.authorizationHeader: 'Bearer $token',
    HttpHeaders.contentTypeHeader: 'application/json; charset=UTF-8',
    HttpHeaders.acceptHeader: 'application/json',
  });
  // other codes as 200 and 400 are not documented, however 404 is a user not found error, every other error should be reported to fix issues
  if (response.statusCode != 200 && response.statusCode != 404) {
    throw Error();
  }
  if (response.statusCode == 404) {
    throw Error();
  }
  final responseJson = jsonDecode(utf8.decode(response.bodyBytes));
  User? user;
  try {
    user = User.fromJson(responseJson);
  } catch (error, stackTrace) {
    Catcher2.reportCheckedError(error, stackTrace);
  }
  if (user != null) {
    return user;
  }
  // throw error otherwise.. we shouldn't arrive here, but this needs to be done to compile..
  throw Error();
}
