
import 'package:flutter/material.dart';
import 'package:snipe_scanner/main.dart';
import 'package:snipe_scanner/utils/zebra_scan.dart';

// this class can be extended by view widgets to get the scanning functionality by overriding the onScan method. as it already has all the functionality to load data when a view gets added into the app you can do that aswell by overriding the loadData method
abstract class ScanAwareState<T> extends State with RouteAware {
  void onScan(String barcode) {}
  void loadData() {}

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    routeObserver.subscribe(this, ModalRoute.of(context) as PageRoute);
  }

  // unsubscribe when the view gets disposed
  @override
  void dispose() {
    routeObserver.unsubscribe(this);
    super.dispose();
  }

  // Bin zu Widget hin navigiert.
  @override
  void didPush() {
    loadData();
    ZebraScan.setScanHandler(onScan);
    super.didPush();
  }

  // War bei Widget, hab zurück gedrückt
  @override
  void didPop() {
    ZebraScan.unsetScanHandler(onScan);
    super.didPop();
  }

  // Bin zu Widget zurück gekommen.
  @override
  void didPopNext() {
    loadData();
    ZebraScan.setScanHandler(onScan);
    super.didPopNext();
  }

  // Bin von Widget weg navigiert
  @override
  void didPushNext() {
    ZebraScan.unsetScanHandler(onScan);
    super.didPushNext();
  }
}
