import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:snipe_scanner/components/asset_row.dart';
import 'package:snipe_scanner/components/location_selector.dart';
import 'package:snipe_scanner/components/manual_input.dart';
import 'package:snipe_scanner/model/app_state.dart';
import 'package:snipe_scanner/model/asset.dart';
import 'package:snipe_scanner/service/asset.dart';
import 'package:snipe_scanner/utils/audio.dart';
import 'package:snipe_scanner/utils/scan_aware_state.dart';

class Audit extends StatefulWidget {
  const Audit({super.key});

  @override
  ScanAwareState<Audit> createState() => _AuditState();
}

class _AuditState extends ScanAwareState<Audit> {
  final List<dynamic> _history = [];
  final TextEditingController _noteController = TextEditingController();

  int _dst = -1;
  bool _keepNote = false;

  @override
  void dispose() {
    _noteController.dispose();
    super.dispose();
  }

  @override
  void onScan(String barcode) async {
    var token = Provider.of<AppState>(context, listen: false).token;
    Map<String, dynamic> item = {"barcode": barcode};
    setState(() {
      _history.add(item);
    });
    Asset asset;
    try {
      asset = await getAssetFromTag(token, barcode);
    } catch (err) {
      playFail();
      setState(() {
        item["status"] = false;
      });
      return;
    }
    playSuccess();
    setState(() {
      item["name"] = asset.getShortName();
    });
    try {
      await auditAsset(token, asset.assetTag!,
          note: _noteController.text, dstId: _dst);
    } catch (err) {
      setState(() {
        item["status"] = false;
      });
      return;
    }
    setState(() {
      item["note"] = _noteController.text;
      item["status"] = true;
      if (!_keepNote) _noteController.text = "";
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("Bulk Audit"),
        actions: [
          IconButton(
              icon: const Icon(Icons.search),
              tooltip: 'Search for Assets',
              onPressed: () async {
                final result =
                    await Navigator.pushNamed(context, '/searchAsset');
                if (result != null) {
                  onScan('$result');
                }
              }),
        ],
      ),
      body: Column(
        children: [
          LocationSelector(
              instant: true,
              cb: (id) {
                _dst = id;
              }),
          ManualInput(cb: onScan),
          Container(
            margin: const EdgeInsets.symmetric(horizontal: 40),
            child: TextField(
                decoration: const InputDecoration(labelText: "Note"),
                controller: _noteController),
          ),
          SizedBox(
              height: 34,
              child: Row(
                children: [
                  Container(
                    margin: const EdgeInsets.only(left: 40, right: 5),
                    child: Checkbox(
                      value: _keepNote,
                      onChanged: (value) {
                        if (value != null) {
                          setState(() {
                            _keepNote = value;
                          });
                        }
                      },
                    ),
                  ),
                  const Text("Keep note")
                ],
              )),
          Container(
            padding: const EdgeInsets.fromLTRB(20, 0, 20, 4),
            child: const Text(
              "History",
              style: TextStyle(fontWeight: FontWeight.bold, fontSize: 24),
            ),
          ),
          Expanded(
            child: Scrollbar(
                child: ListView.builder(
                    itemCount: _history.length,
                    itemBuilder: (BuildContext context, int index) {
                      var i = _history.length - (index + 1);
                      return assetRow(_history[i]["barcode"], context,
                          name: _history[i]["name"],
                          note: _history[i]["note"],
                          status: _history[i]["status"]);
                    })),
          )
        ],
      ),
    );
  }
}
