import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:snipe_scanner/components/big_button.dart';
import 'package:snipe_scanner/model/app_state.dart';
import 'package:snipe_scanner/model/asset.dart';
import 'package:snipe_scanner/service/asset.dart';

class CheckinAsset extends StatefulWidget {
  const CheckinAsset({super.key});

  @override
  State<CheckinAsset> createState() => _CheckinAssetState();
}

class _CheckinAssetState extends State<CheckinAsset> {
  String _error = "";
  Asset? _asset;
  bool _buttonEnabled = true;
  late TextEditingController _noteController;

  @override
  void initState() {
    _noteController = TextEditingController();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    _asset = ModalRoute.of(context)!.settings.arguments as Asset;

    return Scaffold(
        appBar: AppBar(title: Text("Checkin ${_asset!.getShortName()}")),
        body: Column(
          children: [
            Container(
              alignment: Alignment.center,
              margin: const EdgeInsets.symmetric(horizontal: 40),
              child: TextField(
                  decoration: const InputDecoration(labelText: "Note"),
                  controller: _noteController),
            ),
            Row(
              children: [
                bigButton(
                    "Checkin",
                    _buttonEnabled
                        ? () async {
                            setState(() {
                              _buttonEnabled = false;
                              _error = "";
                            });
                            try {
                              await checkinAsset(
                                  Provider.of<AppState>(context, listen: false)
                                      .token,
                                  _asset!.id,
                                  note: _noteController.text);
                            } catch (e) {
                              setState(() {
                                _error = e.toString();
                                _buttonEnabled = true;
                              });
                              return;
                            }
                            setState(() {
                              _buttonEnabled = true;
                            });
                            if (context.mounted) Navigator.pop(context);
                          }
                        : null),
                if (!_buttonEnabled) const CircularProgressIndicator(),
              ],
            ),
            if (_error != '')
              Container(
                  padding: const EdgeInsets.only(top: 20),
                  child: Text(
                    _error,
                    style: const TextStyle(
                        color: Colors.red, fontWeight: FontWeight.bold),
                  )),
          ],
        ));
  }
}
