import 'package:flutter/material.dart';
import 'package:pref/pref.dart';

class PreferencesWidget extends StatefulWidget {
  const PreferencesWidget({super.key});

  @override
  State<StatefulWidget> createState() => PreferencesWidgetState();
}

class PreferencesWidgetState extends State<PreferencesWidget> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(title: const Text('Settings')),
        body: PrefPage(
          children: [
            PrefText(
              pref: 'host',
              label: 'Host',
              keyboardType: TextInputType.url,
              validator: (str) {
                if (str == null || str == "") {
                  return 'Host is required';
                }
                if (!str.startsWith("http://") && !str.startsWith("https://")) {
                  return 'This needs to include http:// or https://';
                }
                return null;
              },
            ),
            PrefCheckbox(
              pref: 'use_custom_user_url',
              title: const Text("Use custom URL for the user JSON"),
              onChange: (value) {
                if (!value) {
                  PrefService.of(context).set('custom_user_url', '');
                }
              },
            ),
            PrefHider(pref: 'use_custom_user_url', children: [
              PrefText(
                pref: 'custom_user_url',
                label: 'Custom user JSON url',
                keyboardType: TextInputType.url,
                validator: (str) {
                  if (str == null || str == "") {
                    return 'Custom user URL is required';
                  }
                  if (!str.startsWith("http://") &&
                      !str.startsWith("https://")) {
                    return 'This needs to include http:// or https://';
                  }
                  return null;
                },
              ),
            ]),
            const PrefText(pref: 'tag_prefix', label: 'Tag Prefix'),
            PrefCheckbox(
              pref: 'auto_logout',
              title: const Text("Auto Logout"),
              onChange: (value) {
                if (!value) {
                  PrefService.of(context).set('auto_logout_time', 0);
                }
              },
            ),
            const PrefCheckbox(
              pref: 'warn_before_checkin_from_asset',
              title: Text("Warn before checking in an asset from an asset"),
            ),
            PrefHider(pref: 'auto_logout', children: [
              PrefSlider(
                pref: 'auto_logout_time',
                title: const Text('Auto logout timeout'),
                min: 0,
                max: 300,
                trailing: (num v) => Text('$v minutes'),
              ),
            ])
          ],
        ));
  }
}
