import 'package:catcher_2/catcher_2.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:snipe_scanner/components/search_item_row.dart';
import 'package:snipe_scanner/model/app_state.dart';
import 'package:snipe_scanner/model/asset.dart';
import 'package:snipe_scanner/service/asset.dart';

class SearchAsset extends StatefulWidget {
  const SearchAsset({super.key});

  @override
  State<SearchAsset> createState() => _SearchAssetState();
}

class _SearchAssetState extends State<SearchAsset> {
  final TextEditingController _searchController = TextEditingController();
  String _error = "";
  List<Asset> _assets = [];

  @override
  void dispose() {
    _searchController.dispose();
    super.dispose();
  }

  void _search(String value) async {
    setState(() {
      _error = "";
    });
    List<Asset> assets;
    try {
      assets = await getAssets(
          Provider.of<AppState>(context, listen: false).token, value);
    } catch (err, stackTrace) {
      setState(() {
        _error = err.toString();
      });
      Catcher2.reportCheckedError(err, stackTrace);
      return;
    }
    setState(() {
      _assets = assets;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text("Search Asset")),
      body: Column(
        children: [
          if (_error != "")
            Text(
              _error,
              style: const TextStyle(
                  color: Colors.red, fontWeight: FontWeight.bold),
            ),
          Container(
            padding: const EdgeInsets.symmetric(horizontal: 40, vertical: 10),
            child: TextField(
              controller: _searchController,
              decoration: const InputDecoration(label: Text("Search")),
              onSubmitted: (value) => _search(value),
            ),
          ),
          if (_assets.isNotEmpty)
            Container(
                padding: const EdgeInsets.only(bottom: 20, top: 10),
                child: const Text("Results",
                    style:
                        TextStyle(fontSize: 20, fontWeight: FontWeight.bold))),
          if (_assets.isNotEmpty)
            Expanded(
              child: Scrollbar(
                  child: ListView.builder(
                      itemCount: _assets.length,
                      itemBuilder: (BuildContext context, int index) {
                        var i = _assets.length - (index + 1);
                        return searchItemRow(_assets[i], context,
                            cb: (Asset asset) {
                          Navigator.pop(context, asset.assetTag);
                        });
                      })),
            )
        ],
      ),
    );
  }
}
